{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs %}
    <div class="flex items-center space-x-2 breadcrumbs">
        <a class="text-blue-500 hover:underline" href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
        <span class="text-gray-500">&rsaquo;</span>
        <a class="text-blue-500 hover:underline"
           href="{% url 'django-admindocs-docroot' %}">{% translate 'Documentation' %}</a>
        <span class="text-gray-500">&rsaquo;</span>
        <span class="text-gray-500">{% translate 'Bookmarklets' %}</span>
    </div>
{% endblock %}

{% block title %}{% translate 'Documentation Bookmarklets' %}{% endblock %}

{% block content %}
    <p class="text-gray-600">{% blocktranslate %}
        To install bookmarklets, drag the link to your bookmarks toolbar, or right-click
        the link and add it to your bookmarks. You can now select the bookmarklet
        from any page in the site.
    {% endblocktranslate %}</p>

    <div id="content-main" class="space-y-6">
        <h3 class="text-xl text-blue-600">
            <a class="hover:underline"
               href="javascript:(function(){if(typeof XMLHttpRequest!='undefined'){x=new XMLHttpRequest()}else{return;}x.open('HEAD',location.href,false);x.send(null);try{view=x.getResponseHeader('x-view');}catch(e){alert('No view found for this page');return;}if(view=='undefined'){alert('No view found for this page');}document.location='{% url 'django-admindocs-views-index' %}'+view+'/';})()">
                {% translate "Documentation for this page" %}
            </a>
        </h3>
        <p class="text-gray-600">{% translate "Jumps you from any page to the documentation for the view that generates that page." %}</p>
    </div>
{% endblock %}
