{% load i18n %}
{% load admin_urls %}

{% if has_import_permission %}
    <a href='{% url opts|admin_urlname:"import" %}' class="import_link btn  btn-sm">
        {% translate "Import" %} <i class="fa fa-file-import"></i>
    </a>
{% endif %}
