{% load i18n %}
<div>
    <h2 class="font-bold">{% translate "Summary" %}:</h2>
    <ul>
        {% for model_name, object_count in model_count %}
            <li>{{ model_name|capfirst }}: {{ object_count }}</li>
        {% endfor %}
    </ul>
</div>
