{% extends "admin/base_site.html" %}
{% load i18n admin_modify %}
{% load admin_urls %}
{% load static %}

{% block extrastyle %}{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}"/>{% endblock %}
{% block bodyclass %}{{ block.super }} {{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}
{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="text-sm breadcrumbs">
            <ul>
                <li><a href="{% url 'admin:index' %}" class="link link-hover">{% trans 'Dashboard' %}</a></li>
                <li><a href="{% url 'admin:app_list' app_label=opts.app_label %}"
                       class="link link-hover">{{ opts.app_config.verbose_name }}</a></li>
                <li><a class="disabled" href="#">{{ opts.verbose_name_plural|capfirst }}</a></li>
                {% block breadcrumbs_last %}{% endblock %}
            </ul>
        </div>
    {% endblock %}
{% endif %}
