{% extends "admin/import_export/change_list.html" %}

{% block object-tools-items %}
    {% include "admin/import_export/change_list_import_item.html" %}
    {% include "admin/import_export/change_list_export_item.html" %}
    {{ block.super }}
{% endblock %}
