{% load i18n %}
{% block fields_help %}
    <div class="bg-base-100 rounded-box shadow-sm p-4 mb-6">
        <div class="prose prose-sm max-w-none">
            <p class="text-base-content/80">
                {% if import_or_export == "export" %}
                    {% translate "This exporter will export the following fields:" %}
                {% elif import_or_export == "import" %}
                    {% translate "This importer will import the following fields:" %}
                {% endif %}
            </p>
        </div>

        {% if fields_list|length <= 1 %}
            <div class="mt-3 flex flex-wrap gap-2">
                {% for field in fields_list.0.1 %}
                    <span class="kbd  text-sm">
          {{ field }}
        </span>
                {% endfor %}
            </div>
        {% else %}
            <div class="mt-4 space-y-4">
                {% for resource, fields in fields_list %}
                    <div class="border border-base-300 rounded-box bg-base-200/10 p-4">
                        <h3 class="text-lg font-semibold text-base-content mb-2">{{ resource }}</h3>
                        <div class="flex flex-wrap gap-2">
                            {% for field in fields %}
                                <span class="kbd  text-sm">
                {{ field }}
              </span>
                            {% endfor %}
                        </div>
                    </div>
                {% endfor %}
            </div>
        {% endif %}
    </div>
{% endblock %}