{% with id=widget.attrs.id %}<ul style="
    columns: 2;
    -webkit-columns: 2;
    -moz-columns: 2;" {% if id %} id="{{ id }}"{% endif %}>{% for group, options, index in widget.optgroups %}{% if group %}
  <li style="padding: 10px 0;list-style: none;">{{ group }}<ul {% if id %} id="{{ id }}_{{ index }}"{% endif %}>{% endif %}{% for option in options %}
    <li style="padding: 10px 0;list-style: none;">{% include option.template_name with widget=option %}</li>{% endfor %}{% if group %}
  </ul></li>{% endif %}{% endfor %}
</ul>

{% endwith %}
