{% load dash_tags %}
{% with widget=widget|apply_class_to_widget:'input mb-2 w-full min-w-24 max-w-96 focus:outline-0 input-sm input-bordered focus:outline-offset-0' %}
    <input type="{{ widget.type }}" name="{{ widget.name }}" {% if widget.value != None %}
           value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}  >
{% endwith %}
