{% include "django/forms/widgets/url.html" %}
{% if widget.value %}
    <p class="url link text-xs p-2">
        {{ current_label }} <a href="{{ widget.href }}">{{ widget.value }}</a>
    </p>
{% endif %}
